@@ -2,7 +2,7 @@
 
 .. note::
 
-   Implements: https://otrs.github.io/doc/api/otrs/6.0/Perl/index.html
+   Implements: https://doc.otrs.com/doc/api/otrs/8.0/Perl/
 
 """
 
