@@ -1131,12 +1131,12 @@ class Client(object):
         self.session_id_store.value = self.session_id_store.read()
 
         if self.session_id_store.value:
-            # got one.. check whether it's still valid
+            # got one.. use stored is_legacy status info
+            self.use_legacy_sessions = self.session_id_store.is_legacy
+            # and the check whether it's still valid
             if self.session_get(self.session_id_store.value):
                 log.info("Using valid Session ID "
                          "from ({0})".format(self.session_id_store.file_path))
-                # update legacy session with info from store
-                self.use_legacy_sessions = self.session_id_store.is_legacy
                 return True
 
         # got no (valid) session_id; clean store
@@ -2090,7 +2090,7 @@ class Client(object):
                             "HTTP Message: {0.content}".format(response))
         return response
 
-    def _parse_and_validate_response(self, response):
+    def _parse_and_validate_response(self, response): # noqa: max-complexity: 25
         """_parse_and_validate_response
 
         Args:
@@ -2132,10 +2132,23 @@ class Client(object):
 
         # now handle SessionGet operation
         if self.operation in ["SessionGet"]:
-            _session_data = self.result_json.get(self._result_type, None)
+            # For SessionGet the "Result" that is returned is different when legacy session
+            # are used.
+            # SessionData was default in OTRS <= 7 / PyOTRS used it as default from v0.1.
+            # AccessTokenData was introduced in OTRS 8 - for CustomerUser already in 7 (?!).
+            # Unless the dict was modified - use the hardcoded defaults accordingly.
+            if self._result_type not in ["AccessTokenData", "SessionData"]:
+                session_result_type = self._result_type
+            else:
+                if self.use_legacy_sessions:
+                    session_result_type = "SessionData"
+                else:
+                    session_result_type = "AccessTokenData"
+
+            _session_data = self.result_json.get(session_result_type, None)
             if _session_data:  # received SessionData -> Session ID is valid
                 self._result_error = False
-                self.result = self.result_json[self._result_type]
+                self.result = self.result_json[session_result_type]
                 return True
             elif self.result_json["Error"]["ErrorCode"] == "SessionGet.SessionInvalid":
                 return False
